#!/bin/sh

# Install bootloader
# Normally the bootloader partition is locked. We work around this limitation
# by installing a kernel module which enables writing.
# This unlocking module is known as kmod-mtd-rw.
install_bootloader() {
	VERSION_IST=$(strings /dev/mtdblock0 | egrep "U-Boot *[0-9]")
	VERSION_SOL=$(strings uboot.bin | egrep "U-Boot *[0-9]")
	if [ "${VERSION_IST}" != "${VERSION_SOL}" ] ; then
		logger update.sh "Old version is: ${VERSION_IST}, update to: ${VERSION_SOL}"

		insmod mtd-rw i_want_a_brick=1
		mtd write uboot.bin /dev/mtd0

		rmmod mtd-rw
	else
		logger update.sh "Bootloader already up-to-date"
	fi
}

cd /tmp/update

logger update.sh "Cleaning up"
rm -rf /overlay/upper/home/3D/*

logger update.sh "Install bootloader"
if [ -f "uboot.bin" ]; then
	install_bootloader
else
	logger update.sh "Skipping bootloader. No bootloader image found."
fi

logger update.sh "Install kernel..."

# -p           do not attempt to restore the partition table after flash. (Needed because we do the partitioning manually)
sysupgrade -p omega2.bin

exit
